@@ -5,8 +5,8 @@ package Devel::CheckLib;
 use 5.00405; #postfix foreach
 use strict;
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION = '0.9';
-use Config;
+$VERSION = '0.91';
+use Config qw(%Config);
 use Text::ParseWords 'quotewords';
 
 use File::Spec;
@@ -330,7 +330,7 @@ sub _cleanup_exe {
 }
     
 sub _findcc {
-    my @flags = grep { length } map { quotewords('\s+', 0, $_) }
+    my @flags = grep { length } map { quotewords('\s+', 0, $_ || ()) }
         @Config{qw(ccflags ldflags)};
     my @paths = split(/$Config{path_sep}/, $ENV{PATH});
     my @cc = split(/\s+/, $Config{cc});
